==> estateplat-common-1.2.4-20210114.073235-623-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxMzDmxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/11
 * @description 省级信息共享-民政-地名信息
 */
@Table(name = "xxgx_mz_dmxx")
public class XxgxMzDmxx {
    @Id
    private String dmxxid;//地名信息id
    private String xzqdm;//行政区代码
    private String dm;//地名
    private String lsyg;//历史沿革
    private String dmhy;//地名含义
    private String dmll;//地名来历
    private String dmlb;//地名类别
    private String lmzmpx;//罗马字母拼写
    private String proid;//项目id

    public String getDmxxid() {
        return dmxxid;
    }

    public void setDmxxid(String dmxxid) {
        this.dmxxid = dmxxid;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getDm() {
        return dm;
    }

    public void setDm(String dm) {
        this.dm = dm;
    }

    public String getLsyg() {
        return lsyg;
    }

    public void setLsyg(String lsyg) {
        this.lsyg = lsyg;
    }

    public String getDmhy() {
        return dmhy;
    }

    public void setDmhy(String dmhy) {
        this.dmhy = dmhy;
    }

    public String getDmll() {
        return dmll;
    }

    public void setDmll(String dmll) {
        this.dmll = dmll;
    }

    public String getDmlb() {
        return dmlb;
    }

    public void setDmlb(String dmlb) {
        this.dmlb = dmlb;
    }

    public String getLmzmpx() {
        return lmzmpx;
    }

    public void setLmzmpx(String lmzmpx) {
        this.lmzmpx = lmzmpx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20211101.062313-929-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxMzDmxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/11
 * @description 省级信息共享-民政-地名信息(江苏，安徽)
 */
@Table(name = "xxgx_mz_dmxx")
public class XxgxMzDmxx {
    @Id
    private String dmxxid;//地名信息id
    private String xzqdm;//行政区代码,地名编码
    private String dm;//地名,标准地名
    private String lsyg;//历史沿革,地名历史
    private String dmhy;//地名含义,地名释义
    private String dmll;//地名来历,地名来源
    private String dmlb;//地名类别,地名类型
    private String lmzmpx;//罗马字母拼写
    private String proid;//项目id
    private Date cxsj;//查询时间

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }

    public String getDmxxid() {
        return dmxxid;
    }

    public void setDmxxid(String dmxxid) {
        this.dmxxid = dmxxid;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getDm() {
        return dm;
    }

    public void setDm(String dm) {
        this.dm = dm;
    }

    public String getLsyg() {
        return lsyg;
    }

    public void setLsyg(String lsyg) {
        this.lsyg = lsyg;
    }

    public String getDmhy() {
        return dmhy;
    }

    public void setDmhy(String dmhy) {
        this.dmhy = dmhy;
    }

    public String getDmll() {
        return dmll;
    }

    public void setDmll(String dmll) {
        this.dmll = dmll;
    }

    public String getDmlb() {
        return dmlb;
    }

    public void setDmlb(String dmlb) {
        this.dmlb = dmlb;
    }

    public String getLmzmpx() {
        return lmzmpx;
    }

    public void setLmzmpx(String lmzmpx) {
        this.lmzmpx = lmzmpx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}
